@@ -9,15 +9,16 @@ import biosteam as bst
 import thermosteam as tmo
 from thermosteam import Stream
 from biorefineries.cornstover.process_settings import price, ethanol_density_kggal
-from biorefineries.cornstover.chemicals import cornstover_chemicals, get_grouped_chemicals, chemical_groups
+from biorefineries.cornstover.chemicals import cornstover_chemicals, chemical_groups
 from biorefineries.cornstover.tea import CornstoverTEA
 from biorefineries.cornstover import units
 import thermosteam.reaction as rxn
 import numpy as np
 
 bst.CE = 525.4
-System.maxiter = 200
-System.molar_tolerance = 1
+System.maxiter = 400
+System.converge_method = 'Aitken'
+System.molar_tolerance = 0.01
 
 Ethanol_MW = cornstover_chemicals.Ethanol.MW
 Water_MW = cornstover_chemicals.Water.MW
@@ -253,9 +254,9 @@ H401 = bst.HXprocess('H401', ins=(T302-0, None),
 # Beer column
 xbot = Ethanol_molfrac(0.00001)
 ytop = Ethanol_molfrac(0.50)
-D402 = bst.BinaryDistillation('D402', ins=H401-0,
+D402 = bst.BinaryDistillation('D402', ins=H401-0, k=1.25,
                        P=101325, y_top=ytop, x_bot=xbot,
-                       k=1.25, LHK=('Ethanol', 'Water'))
+                       LHK=('Ethanol', 'Water'))
 D402.tray_material = 'Stainless steel 304'
 D402.vessel_material = 'Stainless steel 304'
 D402.BM = 2.4
@@ -505,7 +506,7 @@ S604 = bst.Splitter('S604', ins=S601-0, outs=('treated_water', 'waste_brine'),
                   split={'Water': 0.987})
 
 aerobic_digestion_sys = System('aerobic_digestion_sys',
-                               path=(M602, R602, S601, S602, M604, S603, M603),
+                               path=(M602, update_aerobic_input_streams, R602, S601, S602, M604, S603, M603),
                                recycle=M602-0)
 
 # %% Facilities
@@ -523,19 +524,19 @@ CWP = bst.facilities.ChilledWaterPackage('CWP')
 CT = bst.facilities.CoolingTower('CT')
 CT.outs[1].T = 273.15 + 28
 water_thermo = tmo.Thermo(tmo.Chemicals(['Water']))
-process_water = tmo.Stream(ID='process_water',
-                           thermo=water_thermo)
 
-process_water_streams = (caustic, stripping_water,  warm_process_water, steam, BT-1, CT-1)
-
-def update_water_loss():
-    process_water.imol['Water'] = sum([i.imol['Water'] for i in process_water_streams])
+process_water_streams = (caustic,
+                         stripping_water,
+                         warm_process_water,
+                         steam, BT-1, CT-1)
         
 makeup_water = Stream('makeup_water', thermo=water_thermo, price=price['Makeup water'])
 
 PWC = bst.facilities.ProcessWaterCenter('PWC',
-                                        ins=(S604-0, makeup_water),
-                                        outs=(process_water,))
+                                        (S604-0, makeup_water),
+                                        (),
+                                        (BT-1, CT-1),
+                                        process_water_streams)
 J4 = BT.outs[-1] - bst.Junction('J4') - 2**M601
 J5 = CT.outs[1] - bst.Junction('J5') - 3**M601
 
@@ -572,9 +573,8 @@ FT = units.FireWaterTank('FT',
 cornstover_sys = System('cornstover_sys',
                         path=(pretreatment_sys, fermentation_sys, puresys, J2, S401,
                                  J3, J4, J5, M601, WWTC, R601,
-                                 update_aerobic_input_streams,
                                  aerobic_digestion_sys, S604),
-                        facilities=(M501, CWP, BT, CT, update_water_loss,
+                        facilities=(M501, CWP, BT, CT,
                                     PWC, ADP, update_lime_boilerchems_and_ash,
                                     CIP_package, S301, S302, DAP_storage,
                                     CSL_storage, FT))
@@ -583,23 +583,40 @@ baghouse_bags = Stream(ID='Baghouse_bags', thermo=substance_thermo, flow=(1,), p
 cornstover_sys.feeds.add(lime)
 cornstover_sys.feeds.add(boilerchems)
 cornstover_sys.feeds.add(baghouse_bags)
-aerobic_digestion_sys.converge_method = 'Fixed point'
-for i in range(3): cornstover_sys.simulate()
+for i in range(1): cornstover_sys.simulate()
 ethanol_tea = CornstoverTEA(
-        system=cornstover_sys, IRR=0.10, duration=(2007, 2037),
-        depreciation='MACRS7', income_tax=0.35, operating_days=350.4,
-        lang_factor=None, construction_schedule=(0.08, 0.60, 0.32),
-        startup_months=3, startup_FOCfrac=1, startup_salesfrac=0.5,
-        startup_VOCfrac=0.75, WC_over_FCI=0.05,
-        finance_interest=0.08, finance_years=10, finance_fraction=0.4,
+        system=cornstover_sys, 
+        IRR=0.10, 
+        duration=(2007, 2037),
+        depreciation='MACRS7', 
+        income_tax=0.35,
+        operating_days=350.4,
+        lang_factor=None, 
+        construction_schedule=(0.08, 0.60, 0.32),
+        startup_months=3, 
+        startup_FOCfrac=1,
+        startup_salesfrac=0.5,
+        startup_VOCfrac=0.75,
+        WC_over_FCI=0.05,
+        finance_interest=0.08,
+        finance_years=10,
+        finance_fraction=0.4,
         OSBL_units=(WWTC, CWP, CT, PWC, ADP), # BT not included
-        warehouse=0.04, site_development=0.09, additional_piping=0.045,
-        proratable_costs=0.10, field_expenses=0.10, construction=0.20,
-        contingency=0.10, other_indirect_costs=0.10, labor_cost=2.5e6,
-        labor_burden=0.90, property_insurance=0.007, maintenance=0.03)
+        warehouse=0.04, 
+        site_development=0.09, 
+        additional_piping=0.045,
+        proratable_costs=0.10,
+        field_expenses=0.10,
+        construction=0.20,
+        contingency=0.10,
+        other_indirect_costs=0.10, 
+        labor_cost=2.5e6,
+        labor_burden=0.90,
+        property_insurance=0.007, 
+        maintenance=0.03)
 ethanol_tea.units.remove(BT)
-
-Area700 = bst.TEA.like(System('Area700', (M501, BT,)),
+ethanol_tea.units.remove(U101)
+Area700 = bst.TEA.like(System('Area700', (BT,)),
                        ethanol_tea)
 Area700.labor_cost = 0
 Area700.depreciation = 'MACRS20'
@@ -658,6 +675,6 @@ get_ecost = lambda units: sum([i.power_utility.cost
 
 cooling_water_uses = {i: get_utility(j.units, 'Cooling water', 'duty')/1e6/4.184
                       for i,j in numbered_areas}
+
 electricity_uses = {i: get_rate(j.units)/41 for i,j in numbered_areas}
 electricity_costs = {i: get_ecost(j.units) for i,j in numbered_areas}
-
