@@ -255,7 +255,7 @@ P202-0-PS3
 (C201-1, rvf_wash_water)-C202-1-P203
 
 C201-0-T207-T207_2-0-H203
-(H203-0, oil_wash_water)-T208-C203-0-F201
+(H203-0, oil_wash_water-PS2-0)-T208-C203-0-F201
 T207-T207_2-1-S202
 
 lipid = F201-1
@@ -567,7 +567,7 @@ P406 = units.Pump('P406')
 # Centrifuge out water
 C403 = units.LiquidsRatioCentrifuge('C403',
                          K_chemicals=('Methanol', 'Glycerol'),
-                         Ks=np.array((0.382, 0.183)),
+                         Ks=np.array([0.382, 0.183]),
                          top_solvents=('Biodiesel',),
                          top_split=(0.999,),
                          bot_solvents=('Water', 'Lipid', 'NaOH', 'HCl'),
@@ -622,13 +622,22 @@ x_water = w/(w+g)
 
 D402 = units.BinaryDistillation('D402',
                     LHK=('Water', 'Glycerol'),
-                    k=1.1,
+                    k=1.25,
                     P=101325,
                     y_top=0.999,
                     x_bot=x_water,
                     tray_material='Stainless steel 304',
                     vessel_material='Stainless steel 304')
 
+def startup_water():
+    imol = D402.ins[0].imol
+    water, glycerol = imol['Water', 'Glycerol']
+    minimum_water = 5 * (w / (w + g)) * glycerol
+    if water < minimum_water:
+        imol['Water'] = minimum_water
+        
+PS_startup = bst.ProcessSpecification('PS_startup', specification=startup_water)
+
 # Condense recycle methanol
 H403 = units.HXutility('H403', V=0, T=315)
 P411 = units.Pump('P411')
@@ -658,7 +667,6 @@ oil-T403-P403
 #  0.02 wt % glycerol (lower to 0.015)
 #  0.4 wt % free lipids (lower to 0.35)
 
-
 # Find Water Flow
 def adjust_biodiesel_wash_water():
     total_glycerol =  (C401.outs[1].imol['Glycerol'] + R402.outs[0].imol['Glycerol'])
@@ -687,7 +695,7 @@ F401-0-H401-P408
 C401-1-P405
 (P405-0, C402-1, C403-1, P408-0, HCl2)-T406-P409-C404
 (C404-0, NaOH)-T407-P410
-H402-0-D401-1-D402-1-T408
+H402-0-D401-1-PS_startup-D402-1-T408
 P410-0-H402                
 
 # Mass Balance for Methanol, Recycle Methanol, and Catalyst stream
@@ -725,20 +733,21 @@ BT = units.BoilerTurbogenerator('BT',
 bst.Stream.ticket_number = 600
 
 CT = units.CoolingTower('CT')
-process_water_streams = (stream.biodiesel_wash_water,
-                         stream.cooling_tower_makeup_water,
-                         stream.boiler_makeup_water)
+makeup_water_streams = (stream.cooling_tower_makeup_water,
+                        stream.boiler_makeup_water)
+
+process_water_streams = (stream.imbibition_water,
+                         stream.biodiesel_wash_water,
+                         *makeup_water_streams)
+
 makeup_water = bst.Stream('makeup_water', price=0.000254)
-process_water = bst.Stream('process_water')
-def update_recycled_process_water():
-    process_water.imol['Water'] = sum([stream.imol['Water'] 
-                                       for stream in process_water_streams])
 
 CWP = units.ChilledWaterPackage('CWP')
 PWC = units.ProcessWaterCenter('PWC',
-                               ('recycle_water', makeup_water),
-                               process_water,
-                               update_recycled_process_water)
+                               (M305-0, makeup_water),
+                               (),
+                               makeup_water_streams,
+                               process_water_streams)
 
 connect_lipid = units.Junction('J2', lipid, oil,
                                ('Lipid',))
